@@ -8,14 +8,14 @@ use strict;
 use Compress::Huffman;
 my $cf = Compress::Huffman->new ();
 my %symbols = (
-a => 0.5,
-b => 0.25,
-c => 0.125,
-d => 0.125,
+    a => 0.5,
+    b => 0.25,
+    c => 0.125,
+    d => 0.125,
 );
 $cf->symbols (\%symbols);
 my $table = $cf->table ();
-for my $k (keys %symbols) {
+for my $k (sort keys %symbols) {
     print "$k: <$table->{$k}> ";
 }
 print "\n";
@@ -26,7 +26,7 @@ print "\n";
 $cf->symbols (\%symbols, size => 3, notprob => 1);
 
 my $table3 = $cf->table ();
-for my $k (keys %symbols) {
+for my $k (sort keys %symbols) {
     print "$k: <$table3->{$k}> ";
 }
 print "\n";
